@@ -133,7 +133,8 @@ class FieldsConverter:
                 )
             )
             return type_to
-        if -1 not in self.advanced_features and column["column_default"] is not None and "::" not in column["column_default"]:
+        if -1 not in self.advanced_features and column["column_default"] is not None and "::" not in column[
+            "column_default"]:
             default_from = column["column_default"].lower()
             if default_from in types_converter_dict[self.key]["default"]:
                 default_to = types_converter_dict[self.key]["default"][default_from]
@@ -177,12 +178,16 @@ class FieldsConverter:
         ddl += "\n);\n\n\n"
         return ddl
 
-    def create_ddl(self, table_name):
+    def get_new_types(self, table_name):
         self.db_worker_from.check_if_table_availible(table_name)
         fields = self.db_worker_from.get_table_schema(table_name)
         fields_new = {}
         for f in fields:
             fields_new[f["column_name"]] = self.update_column_type(f)
+        return fields_new
+
+    def create_ddl(self, table_name):
+        fields_new = self.get_new_types(table_name)
         return self.generate_create(fields_new, table_name)
 
     def drop_list_of_tables(self, tables):
